@@ -1,9 +1,12 @@
 #!/bin/bash
 #set -vx
-mversion="V5.2"
-ASTERISK_4="1.4.36"
+mversion="V7.0"
+ASTERISK_4="1.4.43"
 ASTERISK_4_OLD="1.4.11"
+ASTERISK_6_2="1.6.2.22"
+ASTERISK_6_2_OLD="1.6.2.5"
 
+s
 src=.
 dst=
 #src=asterisk_$mversion
@@ -27,9 +30,15 @@ fi
 
 #Check Asterisk Version
 asteriskversion=`asterisk -V| cut -d ' ' -f 2` 
+#Asterisk Versions parsing
+eval `echo $asteriskversion |  sed -n 's_\([0-9]*\)\.\([0-9]*\)\.\([0-9]*\).*_ astver1="\1" astver2="\2" astver3="\3"_p'`
+[ "$astver2" == "6" ] && eval `echo $asteriskversion |  sed -n 's_[0-9]*\.[0-9]*\.[0-9]*\.\([0-9]*\).*_ astver4="\1"_p'`
+echo "Current Asterisk : '$astver1.$astver2.$astver3.$astver4'"
+
+
 case "$asteriskversion" in
   1.4.*)
-    if [ `echo $asteriskversion| cut -d. -f3` -le `echo $ASTERISK_4_OLD|cut -d. -f3` ];then
+    if [ "$astver3" -le `echo $ASTERISK_4_OLD|cut -d. -f3` ];then
       astflavour=$ASTERISK_4_OLD
     else
       astflavour=$ASTERISK_4
@@ -40,7 +49,14 @@ case "$asteriskversion" in
   1.6.1.*)
     astflavour="1.6.1";;
   1.6.2.*)
-    astflavour="1.6.2";;
+    if [ "$astver4" -le `echo $ASTERISK_6_2_OLD|cut -d. -f4` ];then
+      astflavour=$ASTERISK_6_2_OLD
+    else
+      astflavour=$ASTERISK_6_2
+    fi
+    ;;
+  1.8*)
+    astflavour="1.8";;
   *)
     echo "Unknow Asterisk Version: '$asteriskversion', exiting"
     exit 1;;
